---
layout: post
permalink: /libs/val_to_id/
title: val_to_id.dots
---

### Purpose
This librairy sets the id of a dot to its value

### Usage
    
     T
    L+R
     B

##### Parameters
- `L`, `R`, `T` or `B`: The dot to change it id
- `R`, `L`, `B` or `T`: The dot will be go out following the same direction

##### Example

    %!val_to_id.dots i

    .-#2-@6-$_@--i--$_@-$_#-&

##### Output

    666
   
### Source 
The source code is availaible [here](https://github.com/aaronjanse/asciidots/blob/master/dots/libs/val_to_id.dots)
. If something doesn't work, do not hesitate to [open an issue](https://github.com/aaronjanse/asciidots/issues/new?title=Bug%20in%20val_to_id%20library:%20).
